@@ -1,4 +1,4 @@
-//  Copyright (C) 2011 Ben Asselstine
+//  Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -67,6 +67,8 @@ GameWindow::GameWindow()
 {
   game_winner = NULL;
   game = NULL;
+  stack_is_currently_moving = NULL;
+  raft_is_currently_moving = NULL;
     sdl_inited = false;
     
     Glib::RefPtr<Gtk::Builder> xml
@@ -158,7 +160,7 @@ bool GameWindow::on_map_mouse_motion_event(GdkEventMotion *event)
             {
             case DiceBox::NONE:
               map_image->get_window()->set_cursor 
-                (Gdk::Cursor
+                (Gdk::Cursor::create
                  (Gdk::Display::get_default(), 
                   GraphicsCache::getInstance()->getCursorPic (0)->to_pixbuf(), 1, 1));
               break;
@@ -167,7 +169,7 @@ bool GameWindow::on_map_mouse_motion_event(GdkEventMotion *event)
                   active->getActivestack() == NULL)
                 {
                 map_image->get_window()->set_cursor 
-                  (Gdk::Cursor
+                  (Gdk::Cursor::create
                    (Gdk::Display::get_default(), 
                     GraphicsCache::getInstance()->getCursorPic (1)->to_pixbuf(), 7, 7));
                   redraw();
@@ -175,7 +177,7 @@ bool GameWindow::on_map_mouse_motion_event(GdkEventMotion *event)
               else
                 {
                   map_image->get_window()->set_cursor 
-                    (Gdk::Cursor
+                    (Gdk::Cursor::create
                      (Gdk::Display::get_default(), 
                       GraphicsCache::getInstance()->getCursorPic (1)->to_pixbuf(), 7, 7));
                   redraw();
@@ -187,7 +189,7 @@ bool GameWindow::on_map_mouse_motion_event(GdkEventMotion *event)
                   active->getActivestack() == NULL)
                 {
                 map_image->get_window()->set_cursor 
-                  (Gdk::Cursor
+                  (Gdk::Cursor::create
                    (Gdk::Display::get_default(), 
                     GraphicsCache::getInstance()->getCursorPic (1)->to_pixbuf(), 7, 7));
                 redraw();
@@ -195,7 +197,7 @@ bool GameWindow::on_map_mouse_motion_event(GdkEventMotion *event)
               else
                 {
                 map_image->get_window()->set_cursor 
-                  (Gdk::Cursor
+                  (Gdk::Cursor::create
                    (Gdk::Display::get_default(), 
                     GraphicsCache::getInstance()->getCursorPic (1)->to_pixbuf(), 7, 7));
                 redraw();
@@ -207,6 +209,7 @@ bool GameWindow::on_map_mouse_motion_event(GdkEventMotion *event)
     }
   return true;
 }
+
 bool GameWindow::on_map_mouse_button_event(GdkEventButton *event)
 {
   if (event->type != GDK_BUTTON_PRESS && event->type != GDK_BUTTON_RELEASE)
@@ -553,7 +556,7 @@ void GameWindow::on_fight_started(Fight::Result result, int defender_roll,
 void GameWindow::on_no_dice_left()
 {
   map_image->get_window()->set_cursor 
-    (Gdk::Cursor
+    (Gdk::Cursor::create
      (Gdk::Display::get_default(), 
       GraphicsCache::getInstance()->getCursorPic (0)->to_pixbuf(), 4, 4));
   game->end_turn();
@@ -562,7 +565,7 @@ void GameWindow::on_no_dice_left()
 void GameWindow::on_die_used()
 {
   map_image->get_window()->set_cursor 
-    (Gdk::Cursor
+    (Gdk::Cursor::create
      (Gdk::Display::get_default(), 
       GraphicsCache::getInstance()->getCursorPic (0)->to_pixbuf(), 4, 4));
   Player *player = Playerlist::getActiveplayer();
@@ -627,20 +630,8 @@ void GameWindow::redraw()
       if (active->getActivestack())
         {
           Rectangle rect(current_tile, Vector<int>(1,1));
-          /*
-          Maptile *mtile = GameMap::getInstance()->getTile(current_tile);
-          if (mtile->isWater())
-            map->get_gc()->set_rgb_fg_color(Gdk::Color("blue"));
-          else if (mtile->getType() == Maptile::FOREST)
-            map->get_gc()->set_rgb_fg_color(Gdk::Color("green"));
-          else if (mtile->getType() == Maptile::BRICK)
-            map->get_gc()->set_rgb_fg_color(Gdk::Color("red"));
-          else
-            */
-            map->get_gc()->set_rgb_fg_color(Gdk::Color("brown"));
-          map->get_pixmap()->draw_rectangle(map->get_gc(), false, 
-                                            rect.x*ts, rect.y*ts, 
-                                            rect.w*ts, rect.h*ts);
+          map->set_source_rgba(Gdk::RGBA("brown"));
+          map->draw_rectangle(rect.x*ts, rect.y*ts, rect.w*ts, rect.h*ts);
         }
     }
 
@@ -664,19 +655,15 @@ void GameWindow::redraw()
               rect.pos = new_pos;
             }
           //draw the box
-          map->get_gc()->set_rgb_fg_color(Gdk::Color("yellow"));
-          map->get_pixmap()->draw_rectangle(map->get_gc(), false, 
-                                            rect.x*ts, rect.y*ts, 
-                                            rect.w*ts, rect.h*ts);
+          map->set_source_rgba(Gdk::RGBA("yellow"));
+          map->draw_rectangle(rect.x*ts, rect.y*ts, rect.w*ts, rect.h*ts);
           selected_move_box = rect;
         }
       else if (mode == DiceBox::MOVE && stack_is_currently_moving && raft_is_currently_moving == NULL)
         {
           Rectangle rect = selected_move_box;
-          map->get_gc()->set_rgb_fg_color(Gdk::Color("yellow"));
-          map->get_pixmap()->draw_rectangle(map->get_gc(), false, 
-                                            rect.x*ts, rect.y*ts, 
-                                            rect.w*ts, rect.h*ts);
+          map->set_source_rgba(Gdk::RGBA("yellow"));
+          map->draw_rectangle(rect.x*ts, rect.y*ts, rect.w*ts, rect.h*ts);
         }
       else if (mode == DiceBox::ATTACK)
         {
@@ -692,10 +679,8 @@ void GameWindow::redraw()
               rect.pos = new_pos;
             }
           //draw the box
-          map->get_gc()->set_rgb_fg_color(Gdk::Color("red"));
-          map->get_pixmap()->draw_rectangle(map->get_gc(), false, 
-                                            rect.x*ts, rect.y*ts, 
-                                            rect.w*ts, rect.h*ts);
+          map->set_source_rgba(Gdk::RGBA("red"));
+          map->draw_rectangle(rect.x*ts, rect.y*ts, rect.w*ts, rect.h*ts);
           selected_attack_box = rect;
         }
 
@@ -728,8 +713,8 @@ bool GameWindow::on_delete_event(GdkEventAny *e)
 void GameWindow::on_load_game_activated()
 {
   Gtk::FileChooserDialog chooser(*window, "Choose Game to Load");
-  Gtk::FileFilter sav_filter;
-  sav_filter.add_pattern("*" + SAVE_EXT);
+  Glib::RefPtr<Gtk::FileFilter> sav_filter = Gtk::FileFilter::create();
+  sav_filter->add_pattern("*" + SAVE_EXT);
   chooser.set_filter(sav_filter);
   chooser.set_current_folder(Configuration::s_savePath);
 
@@ -770,8 +755,8 @@ void GameWindow::on_save_game_as_activated()
 {
   Gtk::FileChooserDialog chooser(*window, "Choose a Name",
 				 Gtk::FILE_CHOOSER_ACTION_SAVE);
-  Gtk::FileFilter sav_filter;
-  sav_filter.add_pattern("*" + SAVE_EXT);
+  Glib::RefPtr<Gtk::FileFilter> sav_filter = Gtk::FileFilter::create();
+  sav_filter->add_pattern("*" + SAVE_EXT);
   chooser.set_filter(sav_filter);
   chooser.set_current_folder(Configuration::s_savePath);
 
@@ -1175,6 +1160,7 @@ void GameWindow::give_some_cheese(Player *winner)
 void GameWindow::on_preferences_activated()
 {
   PreferencesDialog d;
+  d.set_parent_window(*window);
   d.run();
   d.hide();
 }
